@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd ;
-$Config::Model::Backend::Systemd::VERSION = '0.232.3';
+$Config::Model::Backend::Systemd::VERSION = '0.232.4';
 use strict;
 use warnings;
 use 5.010;
@@ -42,9 +42,6 @@ sub read {
     # check      => yes|no|skip
 
 
-    my $dir = path($args{root}.$args{config_dir});
-    die "Unknown directory $dir" unless $dir->is_dir;
-
     # load layers
     foreach my $layer ($self->default_directories) {
         my $dir = path ($args{root}.$layer);
@@ -60,6 +57,13 @@ sub read {
         }
     }
 
+    my $dir = path($args{root}.$args{config_dir});
+
+    if (not $dir->is_dir) {
+        $logger->debug("skipping missing directory $dir");
+        return 1 ;
+    }
+
     $self->config_dir($dir);
     foreach my $file ($dir->children($filter) ) {
         my ($unit_type) = ($file =~ $filter);
@@ -125,7 +129,7 @@ Config::Model::Backend::Systemd - R/W backend for systemd configurations files
 
 =head1 VERSION
 
-version 0.232.3
+version 0.232.4
 
 =head1 SYNOPSIS
 
