@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Unit ;
-$Config::Model::Backend::Systemd::Unit::VERSION = '0.232.3';
+$Config::Model::Backend::Systemd::Unit::VERSION = '0.232.4';
 use strict;
 use warnings;
 use 5.010;
@@ -42,9 +42,6 @@ sub read {
         return $self->SUPER::read(%args);
     };
 
-    my $dir = path($args{root}.$args{config_dir});
-    die "Unknown directory $dir" unless $dir->is_dir;
-
     my $unit_type = $self->node->element_name;
     my $unit_name   = $self->node->index_value;
 
@@ -71,7 +68,8 @@ sub read {
     }
     $self->node->instance->layered_stop;
 
-    if (path($args{file_path})->realpath eq '/dev/null') {
+    my $file_path = path($args{file_path});
+    if ($file_path->exists and $file_path->realpath eq '/dev/null') {
         $logger->debug("skipping  unit $unit_type name $unit_name from ".$args{config_dir});
     }
     else {
@@ -205,7 +203,7 @@ Config::Model::Backend::Systemd::Unit - R/W backend for systemd unit files
 
 =head1 VERSION
 
-version 0.232.3
+version 0.232.4
 
 =head1 SYNOPSIS
 
